# Generated by ariadne-codegen on 2023-06-07 11:07
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import EntitlementsUpdatedPayload


class EntitlementsUpdated(BaseModel):
    entitlements_updated: "EntitlementsUpdatedEntitlementsUpdated" = Field(
        alias="entitlementsUpdated"
    )


class EntitlementsUpdatedEntitlementsUpdated(EntitlementsUpdatedPayload):
    pass


EntitlementsUpdated.update_forward_refs()
EntitlementsUpdatedEntitlementsUpdated.update_forward_refs()
