# Generated by ariadne-codegen on 2023-06-07 11:07
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel


class InitiateCheckout(BaseModel):
    initiate_checkout: "InitiateCheckoutInitiateCheckout" = Field(
        alias="initiateCheckout"
    )


class InitiateCheckoutInitiateCheckout(BaseModel):
    checkout_url: str = Field(alias="checkoutUrl")
    checkout_billing_id: str = Field(alias="checkoutBillingId")


InitiateCheckout.update_forward_refs()
InitiateCheckoutInitiateCheckout.update_forward_refs()
