# Generated by ariadne-codegen on 2023-06-07 11:07
# Source: operations.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetSdkConfiguration(BaseModel):
    sdk_configuration: Optional["GetSdkConfigurationSdkConfiguration"] = Field(
        alias="sdkConfiguration"
    )


class GetSdkConfigurationSdkConfiguration(BaseModel):
    sentry_dsn: Optional[str] = Field(alias="sentryDsn")
    is_widget_watermark_enabled: Optional[bool] = Field(
        alias="isWidgetWatermarkEnabled"
    )


GetSdkConfiguration.update_forward_refs()
GetSdkConfigurationSdkConfiguration.update_forward_refs()
