# Generated by ariadne-codegen on 2023-06-07 11:07
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import EntitlementUsageUpdated


class UsageUpdated(BaseModel):
    usage_updated: "UsageUpdatedUsageUpdated" = Field(alias="usageUpdated")


class UsageUpdatedUsageUpdated(EntitlementUsageUpdated):
    pass


UsageUpdated.update_forward_refs()
UsageUpdatedUsageUpdated.update_forward_refs()
